pro ssc_scan2,year,month=month,decaday=decaday,nfils=nfils,$
	debug=debug,sscdir=sscdir,term=term,nouncert=nouncert

;+
;  NAME:  ssc_scan2
;
;  PURPOSE: Program to compare TermSFC and SynSFC versions
;	of SSCs.  
;
;  PROCEDURE
;	One day of data are read in according to keyword
;	input.  A log scaled 1024x512 data cube,
;	with Terms on the left and Syns on the right, is prepared.  
;	Initially, all stepper2 output flags are set to 0 which
;	means SynSFCs are selected.  However, if keyword(term) has
;	been set the flag indices are all set to 1 as it is
;	anticipated that most images will use TermSFCs as will
;	be the case, e.g., for leak epochs 1 and 2.
;	A small AlMg image is displayed in the upper RH corner
;	for comparison purposes.
;
;	Selection flags can be toggled in the stepper2.pro fashion.  
;	After the selection process is complete an sda data
;	file is written from the Term and Syn selections
;	combined.  The saved AlMg selections are always SynSFCs.
;
;  CALLING EXAMPLE:
;       ssc_scan2,1993,decaday='013',nfils=[0,1],$
;          /debug
;
;  INPUT:
;	year, year to be analyzed
;
;  OPTIONAL KEYWORD INPUT:
;	month, month to be analyzed, e.g., month='03'
;	decaday, month_10day triplet, i.e., '092' 
;       nfils, vector of files to be analyzed
;	   Default: all available files for that year.
;	term, /term selects Al.1 TermSFCS as the initial choice.
;	/sscdir, write output to '/disk/yl1/ssc7/'+year+'/'
;		else write output to curcurrent directory.
;	/nouncert, don"t deal with the uncertainty files (for testing).
;
;  OUTPUT:
;	An sda file is written with mixes TermSFC and SynSFC
;	usage, as selected, for Al.1 SSCs.
;
;  RESTRICTIONS:
;	Hardwired to use /data/yl1/ssc6 and /data/yl1/SynSFC/ssc6.
;	Output to either curdir or /data/yl1/ssc7.  In the latter
;	case the job must be run as software.
;
;  HISTORY:
;	11-Oct-2004 LWA  Created from ssc_scan.pro.
;	12-Oct-2004 LWA  Put QR AlMg image in UR corner.
;	 8-Nov-2004 LWA  Editted header.
;-

start_time = systime(1)
run_time = 0.
debug = keyword_set(debug)
term = keyword_set(term)
year=strtrim(year,2)
if not keyword_set(sscdir) then begin
   outdir=curdir()+'/'
endif else begin
   outdir='/disk/yl1/ssc7/'+strtrim(year,2)+'/'
endelse

if keyword_set(month) and keyword_set(decaday) then begin
   print,  'YOU CANNOT SIMULTANEOUSLY USE BOTH KEYWORDS "month"	AND "decaday."'
   return
endif

sdir='/disk/yl1/SynSFC/ssc6/'+strtrim(year,2)
tdir='/disk/yl1/ssc6/'+strtrim(year,2)

case 1 of
   keyword_set(month) : begin
      sfil=findfile(sdir+'/ssc'+strtrim(year,2)+month+'*1.1')
      sfilu=findfile(sdir+'/ssc'+strtrim(year,2)+month+'*1.1_unc')
      tfil=findfile(tdir+'/ssc'+strtrim(year,2)+month+'*0.1')
      tfilu=findfile(tdir+'/ssc'+strtrim(year,2)+month+'*0.1_unc')
   end   
   keyword_set(decaday) : begin
      sfil=findfile(sdir+'/ssc'+strtrim(year,2)+decaday+'*1.1')
      tfil=findfile(tdir+'/ssc'+strtrim(year,2)+decaday+'*0.1')
   end   
   else : begin	
   sfil=findfile(sdir+'/*1.1')
   sfilu=findfile(sdir+'/*1.1_unc')
   tfil=findfile(tdir+'/*0.1')
   tfilu=findfile(tdir+'/*0.1_unc')
   end
endcase   
if strmatch(year,'1992') and NOT keyword_set(decaday) then begin
  if not keyword_set(month) or month eq '11' then begin
     yr=strwhere(tfil,'*19921114*')
     tfil=tfil(yr(0):n_elements(tfil)-1)
     tfilu=tfilu(yr(0):n_elements(tfil)-1)
  endif
endif  
if debug then stop

if n_elements(nfils) eq 0 then nfils=indgen(n_elements(sfil)) $
   else nfilsr=nfils
loadct,15
wdef,dummy,/free,1024,512,/ur

for i=nfils(0),nfils(n_elements(nfils)-1) do begin
   print,i,'   ',sfil(i),'   ',tfil(i)
   rd_xda,sfil(i),-1,sind,sdat
   rd_xda,tfil(i),-1,tind,tdat
   index=sind
   data=sdat
   al=where(gt_filtb(sind) eq 2 and gt_res(sind) eq 1,nal)
   dg=where(gt_filtb(sind) eq 3)
   dgx=tim2dset(index(dg),index(al))
   if nal gt 0 then begin
      cube=bytarr(1024,512,n_elements(al))
      for j=0,n_elements(al)-1 do begin
         cube(0:511,*,j)=bytscl(safe_log10(tdat(*,*,al(j))))     
         cube(512:1023,*,j)=bytscl(safe_log10(sdat(*,*,al(j))))     
	 case 1 of
	    gt_res(index(dg(dgx(j)))) eq 2 : $
	       cube(768:1023,256:511,j)= $
	       bytscl(safe_log10(data(0:255,0:255,dg(dgx(j)))))
	    gt_res(index(dg(dgx(j)))) eq 1 : $
	       cube(768:1023,256:511,j)= $
	       rebin(bytscl(safe_log10(data(*,*,dg(dgx(j))))),256,256)
         endcase
      endfor   
      flags=stepper2(index(al),cube,wunz=term)
      tt=where(flags eq 1,ntt)
      if ntt gt 0 then begin
         index(al(tt))=tind(al(tt))
         data(*,*,al(tt))=tdat(*,*,al(tt))
         nam=outdir+strmid(tfil(i),20,23)+'x.1'	;Output file name.
         sav_sda,nam,index,data
	 if NOT keyword_set(nouncert) then begin
            rd_xda,sfilu(i),-1,sindu,sdatu
	    rd_xda,tfilu(i),-1,tindu,tdatu
	    sindu(al(tt))=tindu(al(tt))
	    sdatu(*,*,al(tt))=tdatu(*,*,al(tt))
	    nam=outdir+strmid(tfil(i),20,23)+'x.1_unc'
	    sav_sda,nam,sindu,sdatu
         endif   
      endif	 
   endif else begin
      print,'  No Al.1 images, writing pure SynSFC output file.  '	   
      nam=outdir+strmid(tfil(i),20,23)+'1.1'	;Output file name.
      sav_sda,nam,index,data
	 if NOT keyword_set(nouncert) then begin
            rd_xda,sfilu(i),-1,sindu,sdatu
	    nam=outdir+strmid(tfil(i),20,23)+'1.1_unc'
	    sav_sda,nam,sindu,sdatu
        endif   
   endelse   
if keyword_set(debug) then stop
endfor
end_time = systime(1)
run_time = (end_time-start_time)/60.
print, 'SSC_SCAN: ', run_time, ' minutes to process your request'

end

